package ru.landgrafhomyak.serdha.api.v0.module

import kotlin.jvm.JvmName
import ru.landgrafhomyak.serdha.api.v0.runtime.SynchronizedDatabase

/**
 * Descriptor of synchronized module. Used for schema manipulations.
 */
public interface Module<ModuleUserExtension : Any> {
	/**
	 * Reference user's extension with descriptors related to this module for use in runtime.
	 */
	@Suppress("INAPPLICABLE_JVM_NAME")
	@get:JvmName("userExtension")
	public val userExtension: ModuleUserExtension
	/**
	 * Version key internally used for automatically [upgrading modules][ModuleTemplate.CreateModuleTemplatesScope.upgradeTemplate]. For debugging.
	 */
	@Suppress("INAPPLICABLE_JVM_NAME")
	@get:JvmName("versionKey")
	public val versionKey: String

	/**
	 * Database in which this module was synchronized. For debugging.
	 */
	@Suppress("INAPPLICABLE_JVM_NAME")
	@get:JvmName("ownerDatabase")
	public val ownerDatabase: SynchronizedDatabase<*>
}